diff scripts/legacy/@inline/vectorize.m @ 30893:e1788b1a315f

maint: Use "fcn" as preferred abbreviation for "function" in m-files. * accumarray.m, accumdim.m, quadl.m, quadv.m, randi.m, structfun.m, __is_function__.m, uigetfile.m, uimenu.m, uiputfile.m, doc_cache_create.m, colorspace_conversion_input_check.m, imageIO.m, argnames.m, vectorize.m, vectorize.m, normest1.m, inputname.m, nthargout.m, display_info_file.m, decic.m, ode15i.m, ode15s.m, ode23.m, ode23s.m, ode45.m, odeset.m, check_default_input.m, integrate_adaptive.m, ode_event_handler.m, runge_kutta_23.m, runge_kutta_23s.m, runge_kutta_45_dorpri.m, runge_kutta_interpolate.m, starting_stepsize.m, __all_opts__.m, fminbnd.m, fminsearch.m, fminunc.m, fsolve.m, fzero.m, sqp.m, fplot.m, plotyy.m, __bar__.m, __ezplot__.m, flat_entry.html, profexport.m, movfun.m, bicg.m, bicgstab.m, cgs.m, eigs.m, gmres.m, pcg.m, __alltohandles__.m, __sprand__.m, qmr.m, tfqmr.m, dump_demos.m: Replace "func", "fun", "fn" in documentation and variable names with "fcn".
author Rik <rik@octave.org>
date Mon, 04 Apr 2022 18:14:56 -0700
parents 796f54d4ddbf
children 78c3dcadf130
line wrap: on
line diff
--- a/scripts/legacy/@inline/vectorize.m	Mon Apr 04 11:22:26 2022 -0700
+++ b/scripts/legacy/@inline/vectorize.m	Mon Apr 04 18:14:56 2022 -0700
@@ -24,8 +24,8 @@
 ########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {} vectorize (@var{fun})
 ## Create a vectorized version of the inline function @var{fun} by
 ## replacing all occurrences of @code{*}, @code{/}, etc., with
 ## @code{.*}, @code{./}, etc.
 ##
@@ -47,15 +47,15 @@
 ## The following function was translated directly from the original C++
 ## version.  Yes, it will be slow, but the use of inline functions is
 ## strongly discouraged anyway, and most expressions will probably be
-## short.  It may also be buggy.  Well, don't use this object!  Use
+## short.  It may also be buggy.  Well, don't use this function!  Use
 ## function handles instead!
 
-function fcn = vectorize (obj)
+function vfcn = vectorize (fcn)
 
   if (nargin < 1)
     print_usage ();
   endif
 
-  fcn = inline (__vectorize__ (obj.expr));
+  vfcn = inline (__vectorize__ (fcn.expr));
 
 endfunction
@@ -24,8 +24,8 @@
 
 ## -*- texinfo -*-
-## @deftypefn {} {} vectorize (@var{fun})
-## Create a vectorized version of the inline function @var{fun} by
+## @deftypefn {} {@var{vfcn} =} vectorize (@var{fcn})
+## Create a vectorized version of the inline function @var{fcn} by
 ## replacing all occurrences of @code{*}, @code{/}, etc., with
 ## @code{.*}, @code{./}, etc.